darkhistory.low\_energy.lowE\_electrons.make\_interpolator
==========================================================

.. currentmodule:: darkhistory.low_energy.lowE_electrons

.. autofunction:: make_interpolator